<p align="center">
  <a href="https://github.com/mondeja/mdpo"><img src="https://raw.githubusercontent.com/mondeja/mdpo/master/mdpo.png" alt="mdpo" width="400"></a>
</h1>

<h4 align="center">Markdown files translation using PO files</h4>

<p align="center">
  <a href="https://pypi.org/project/mdpo/">
    <img src="https://img.shields.io/pypi/v/mdpo?logo=pypi&logoColor=white"
         alt="PyPI">
  </a>
  <a href="https://pypi.org/project/mdpo/">
    <img src="https://img.shields.io/pypi/pyversions/mdpo?logo=python&logoColor=white&labelColor=333333">
  </a>
  <a href="https://github.com/mondeja/mdpo/blob/master/LICENSE">
    <img src="https://img.shields.io/pypi/l/mdpo?color=light-green&logo=freebsd&logoColor=white">
  </a>
</p>

<h2 align="center">
  <a href="https://mondeja.github.io/mdpo/">Documentation</a>
</h2>

<p align="center">
Complies with the <a href="https://spec.commonmark.org/">CommonMark Specification</a>, supporting some additional features.</p>

## Status

[![Documentation status][docs-image]][docs-link]
[![Tests][tests-image]][tests-link]
[![Coverage status][coverage-image]][coverage-link]

## Installation

### Python package

```bash
pip install mdpo
```

### Standalone pre-built binaries

Download latest binaries for each CLI tool from [releases].

[tests-image]: https://img.shields.io/github/actions/workflow/status/mondeja/mdpo/ci.yml?logo=github&label=tests&branch=master
[tests-link]: https://github.com/mondeja/mdpo/actions?query=workflow%3ACI
[coverage-image]: https://img.shields.io/codecov/c/github/mondeja/mdpo?logo=codecov&logoColor=white
[coverage-link]: https://app.codecov.io/gh/mondeja/mdpo
[docs-image]: https://img.shields.io/github/actions/workflow/status/mondeja/mdpo/ci.yml?label=docs&logo=readthedocs&logoColor=white&branch=master
[docs-link]: https://mondeja.github.io/mdpo/
[releases]: https://github.com/mondeja/mdpo/releases
